@@ -555,7 +555,7 @@ sub new {
 		ACTIONS => {
 			'OPANG' => 47
 		},
-		DEFAULT => -97
+		DEFAULT => -99
 	},
 	{#State 2
 		ACTIONS => {
@@ -615,10 +615,10 @@ sub new {
 		}
 	},
 	{#State 4
-		DEFAULT => -62
+		DEFAULT => -61
 	},
 	{#State 5
-		DEFAULT => -23
+		DEFAULT => -22
 	},
 	{#State 6
 		ACTIONS => {
@@ -673,13 +673,13 @@ sub new {
 		}
 	},
 	{#State 11
-		DEFAULT => -24
+		DEFAULT => -23
 	},
 	{#State 12
-		DEFAULT => -95
+		DEFAULT => -97
 	},
 	{#State 13
-		DEFAULT => -96
+		DEFAULT => -98
 	},
 	{#State 14
 		ACTIONS => {
@@ -690,7 +690,7 @@ sub new {
 		ACTIONS => {
 			"int" => 57
 		},
-		DEFAULT => -104
+		DEFAULT => -106
 	},
 	{#State 16
 		DEFAULT => -1
@@ -709,7 +709,7 @@ sub new {
 		ACTIONS => {
 			"int" => 60
 		},
-		DEFAULT => -103
+		DEFAULT => -105
 	},
 	{#State 20
 		ACTIONS => {
@@ -720,13 +720,13 @@ sub new {
 		DEFAULT => -4
 	},
 	{#State 22
-		DEFAULT => -101
+		DEFAULT => -103
 	},
 	{#State 23
 		ACTIONS => {
 			'DCOLON' => 63
 		},
-		DEFAULT => -110,
+		DEFAULT => -112,
 		GOTOS => {
 			'class_suffix' => 62
 		}
@@ -741,7 +741,7 @@ sub new {
 			'STAR' => 66,
 			'AMP' => 65
 		},
-		DEFAULT => -92
+		DEFAULT => -94
 	},
 	{#State 26
 		DEFAULT => -6
@@ -752,7 +752,7 @@ sub new {
 		}
 	},
 	{#State 28
-		DEFAULT => -139
+		DEFAULT => -144
 	},
 	{#State 29
 		DEFAULT => -13
@@ -773,7 +773,7 @@ sub new {
 		}
 	},
 	{#State 32
-		DEFAULT => -22
+		DEFAULT => -21
 	},
 	{#State 33
 		ACTIONS => {
@@ -781,7 +781,7 @@ sub new {
 		}
 	},
 	{#State 34
-		DEFAULT => -102
+		DEFAULT => -104
 	},
 	{#State 35
 		ACTIONS => {
@@ -789,7 +789,7 @@ sub new {
 		}
 	},
 	{#State 36
-		DEFAULT => -98
+		DEFAULT => -100
 	},
 	{#State 37
 		ACTIONS => {
@@ -807,7 +807,7 @@ sub new {
 		}
 	},
 	{#State 40
-		DEFAULT => -70,
+		DEFAULT => -69,
 		GOTOS => {
 			'function_metadata' => 78
 		}
@@ -824,7 +824,7 @@ sub new {
 			"int" => 34,
 			"char" => 22
 		},
-		DEFAULT => -99,
+		DEFAULT => -101,
 		GOTOS => {
 			'basic_type' => 80
 		}
@@ -891,16 +891,16 @@ sub new {
 		}
 	},
 	{#State 51
-		DEFAULT => -63
+		DEFAULT => -62
 	},
 	{#State 52
-		DEFAULT => -29
+		DEFAULT => -28
 	},
 	{#State 53
 		ACTIONS => {
 			'COLON' => 87
 		},
-		DEFAULT => -33,
+		DEFAULT => -32,
 		GOTOS => {
 			'base_classes' => 86
 		}
@@ -910,10 +910,10 @@ sub new {
 			'STAR' => 66,
 			'AMP' => 65
 		},
-		DEFAULT => -91
+		DEFAULT => -93
 	},
 	{#State 55
-		DEFAULT => -26
+		DEFAULT => -25
 	},
 	{#State 56
 		ACTIONS => {
@@ -924,7 +924,7 @@ sub new {
 		}
 	},
 	{#State 57
-		DEFAULT => -106
+		DEFAULT => -108
 	},
 	{#State 58
 		ACTIONS => {
@@ -944,7 +944,7 @@ sub new {
 		}
 	},
 	{#State 60
-		DEFAULT => -105
+		DEFAULT => -107
 	},
 	{#State 61
 		ACTIONS => {
@@ -955,7 +955,7 @@ sub new {
 		ACTIONS => {
 			'DCOLON' => 94
 		},
-		DEFAULT => -111
+		DEFAULT => -113
 	},
 	{#State 63
 		ACTIONS => {
@@ -966,22 +966,22 @@ sub new {
 		DEFAULT => -10
 	},
 	{#State 65
-		DEFAULT => -94
+		DEFAULT => -96
 	},
 	{#State 66
-		DEFAULT => -93
+		DEFAULT => -95
 	},
 	{#State 67
 		DEFAULT => -8
 	},
 	{#State 68
-		DEFAULT => -140
+		DEFAULT => -145
 	},
 	{#State 69
-		DEFAULT => -141
+		DEFAULT => -146
 	},
 	{#State 70
-		DEFAULT => -138
+		DEFAULT => -143
 	},
 	{#State 71
 		ACTIONS => {
@@ -998,7 +998,7 @@ sub new {
 		}
 	},
 	{#State 73
-		DEFAULT => -25
+		DEFAULT => -24
 	},
 	{#State 74
 		DEFAULT => -7
@@ -1029,7 +1029,7 @@ sub new {
 			'p_catch' => 109,
 			'p_postcall' => 104
 		},
-		DEFAULT => -64,
+		DEFAULT => -63,
 		GOTOS => {
 			'perc_postcall' => 105,
 			'perc_code' => 101,
@@ -1048,16 +1048,16 @@ sub new {
 		}
 	},
 	{#State 80
-		DEFAULT => -100
+		DEFAULT => -102
 	},
 	{#State 81
-		DEFAULT => -27
+		DEFAULT => -26
 	},
 	{#State 82
 		DEFAULT => -11
 	},
 	{#State 83
-		DEFAULT => -108
+		DEFAULT => -110
 	},
 	{#State 84
 		ACTIONS => {
@@ -1074,7 +1074,7 @@ sub new {
 		ACTIONS => {
 			'COMMA' => 115
 		},
-		DEFAULT => -40,
+		DEFAULT => -39,
 		GOTOS => {
 			'class_metadata' => 114
 		}
@@ -1111,7 +1111,7 @@ sub new {
 		}
 	},
 	{#State 92
-		DEFAULT => -116
+		DEFAULT => -118
 	},
 	{#State 93
 		ACTIONS => {
@@ -1123,7 +1123,7 @@ sub new {
 			"int" => 34,
 			"char" => 22
 		},
-		DEFAULT => -121,
+		DEFAULT => -123,
 		GOTOS => {
 			'type_name' => 12,
 			'class_name' => 1,
@@ -1141,13 +1141,13 @@ sub new {
 		}
 	},
 	{#State 95
-		DEFAULT => -114
+		DEFAULT => -116
 	},
 	{#State 96
-		DEFAULT => -142
+		DEFAULT => -147
 	},
 	{#State 97
-		DEFAULT => -137
+		DEFAULT => -142
 	},
 	{#State 98
 		ACTIONS => {
@@ -1165,7 +1165,7 @@ sub new {
 		}
 	},
 	{#State 101
-		DEFAULT => -77
+		DEFAULT => -76
 	},
 	{#State 102
 		ACTIONS => {
@@ -1177,7 +1177,7 @@ sub new {
 		}
 	},
 	{#State 103
-		DEFAULT => -80
+		DEFAULT => -79
 	},
 	{#State 104
 		ACTIONS => {
@@ -1189,7 +1189,7 @@ sub new {
 		}
 	},
 	{#State 105
-		DEFAULT => -79
+		DEFAULT => -78
 	},
 	{#State 106
 		ACTIONS => {
@@ -1201,10 +1201,10 @@ sub new {
 		}
 	},
 	{#State 107
-		DEFAULT => -78
+		DEFAULT => -77
 	},
 	{#State 108
-		DEFAULT => -69
+		DEFAULT => -68
 	},
 	{#State 109
 		ACTIONS => {
@@ -1217,7 +1217,7 @@ sub new {
 		}
 	},
 	{#State 111
-		DEFAULT => -107
+		DEFAULT => -109
 	},
 	{#State 112
 		ACTIONS => {
@@ -1274,7 +1274,7 @@ sub new {
 		}
 	},
 	{#State 117
-		DEFAULT => -31
+		DEFAULT => -30
 	},
 	{#State 118
 		ACTIONS => {
@@ -1299,13 +1299,13 @@ sub new {
 		}
 	},
 	{#State 120
-		DEFAULT => -83
+		DEFAULT => -82
 	},
 	{#State 121
-		DEFAULT => -81
+		DEFAULT => -80
 	},
 	{#State 122
-		DEFAULT => -86
+		DEFAULT => -85
 	},
 	{#State 123
 		ACTIONS => {
@@ -1334,10 +1334,10 @@ sub new {
 		}
 	},
 	{#State 127
-		DEFAULT => -119
+		DEFAULT => -121
 	},
 	{#State 128
-		DEFAULT => -115
+		DEFAULT => -117
 	},
 	{#State 129
 		ACTIONS => {
@@ -1345,19 +1345,19 @@ sub new {
 		}
 	},
 	{#State 130
-		DEFAULT => -82
+		DEFAULT => -81
 	},
 	{#State 131
-		DEFAULT => -85
+		DEFAULT => -84
 	},
 	{#State 132
-		DEFAULT => -88
+		DEFAULT => -87
 	},
 	{#State 133
-		DEFAULT => -89
+		DEFAULT => -88
 	},
 	{#State 134
-		DEFAULT => -87
+		DEFAULT => -86
 	},
 	{#State 135
 		ACTIONS => {
@@ -1369,10 +1369,10 @@ sub new {
 		}
 	},
 	{#State 136
-		DEFAULT => -84
+		DEFAULT => -83
 	},
 	{#State 137
-		DEFAULT => -109
+		DEFAULT => -111
 	},
 	{#State 138
 		ACTIONS => {
@@ -1380,19 +1380,19 @@ sub new {
 		}
 	},
 	{#State 139
-		DEFAULT => -41,
+		DEFAULT => -40,
 		GOTOS => {
 			'class_body_list' => 157
 		}
 	},
 	{#State 140
-		DEFAULT => -39
+		DEFAULT => -38
 	},
 	{#State 141
-		DEFAULT => -32
+		DEFAULT => -31
 	},
 	{#State 142
-		DEFAULT => -37
+		DEFAULT => -36
 	},
 	{#State 143
 		ACTIONS => {
@@ -1403,19 +1403,19 @@ sub new {
 		}
 	},
 	{#State 144
-		DEFAULT => -34
+		DEFAULT => -33
 	},
 	{#State 145
-		DEFAULT => -36
-	},
-	{#State 146
 		DEFAULT => -35
 	},
+	{#State 146
+		DEFAULT => -34
+	},
 	{#State 147
-		DEFAULT => -118
+		DEFAULT => -120
 	},
 	{#State 148
-		DEFAULT => -117
+		DEFAULT => -119
 	},
 	{#State 149
 		ACTIONS => {
@@ -1426,13 +1426,13 @@ sub new {
 		ACTIONS => {
 			'EQUAL' => 160
 		},
-		DEFAULT => -124
+		DEFAULT => -126
 	},
 	{#State 151
 		ACTIONS => {
 			"const" => 161
 		},
-		DEFAULT => -56,
+		DEFAULT => -55,
 		GOTOS => {
 			'const' => 162
 		}
@@ -1473,7 +1473,7 @@ sub new {
 		}
 	},
 	{#State 154
-		DEFAULT => -112
+		DEFAULT => -114
 	},
 	{#State 155
 		ACTIONS => {
@@ -1540,7 +1540,7 @@ sub new {
 		}
 	},
 	{#State 158
-		DEFAULT => -38
+		DEFAULT => -37
 	},
 	{#State 159
 		ACTIONS => {
@@ -1550,31 +1550,32 @@ sub new {
 	{#State 160
 		ACTIONS => {
 			'ID' => 23,
-			'INTEGER' => 197,
-			'QUOTED_STRING' => 199,
-			'DASH' => 201,
-			'FLOAT' => 200
+			'INTEGER' => 198,
+			'QUOTED_STRING' => 200,
+			'DASH' => 202,
+			'FLOAT' => 201
 		},
 		GOTOS => {
 			'class_name' => 196,
-			'value' => 198
+			'value' => 199,
+			'expression' => 197
 		}
 	},
 	{#State 161
-		DEFAULT => -55
+		DEFAULT => -54
 	},
 	{#State 162
-		DEFAULT => -61
+		DEFAULT => -60
 	},
 	{#State 163
-		DEFAULT => -120
+		DEFAULT => -122
 	},
 	{#State 164
-		DEFAULT => -97
+		DEFAULT => -99
 	},
 	{#State 165
 		ACTIONS => {
-			'CLCURLY' => 202
+			'CLCURLY' => 203
 		}
 	},
 	{#State 166
@@ -1582,20 +1583,21 @@ sub new {
 			'ID' => 23
 		},
 		GOTOS => {
-			'class_name' => 203
+			'class_name' => 204
 		}
 	},
 	{#State 167
-		DEFAULT => -90
+		DEFAULT => -89
 	},
 	{#State 168
 		ACTIONS => {
+			'OPCURLY' => 205,
 			'OPSPECIAL' => 28
 		},
-		DEFAULT => -136,
+		DEFAULT => -141,
 		GOTOS => {
-			'special_blocks' => 205,
-			'special_block' => 204,
+			'special_blocks' => 207,
+			'special_block' => 206,
 			'special_block_start' => 30
 		}
 	},
@@ -1621,18 +1623,18 @@ sub new {
 			'template' => 13,
 			'looks_like_function' => 4,
 			'static' => 169,
-			'perc_name' => 206,
+			'perc_name' => 208,
 			'looks_like_renamed_function' => 192,
-			'nmethod' => 207,
+			'nmethod' => 209,
 			'type' => 20
 		}
 	},
 	{#State 170
-		DEFAULT => -59
+		DEFAULT => -58
 	},
 	{#State 171
 		ACTIONS => {
-			'COLON' => 208
+			'COLON' => 210
 		}
 	},
 	{#State 172
@@ -1651,84 +1653,84 @@ sub new {
 		GOTOS => {
 			'type_name' => 12,
 			'class_name' => 1,
-			'ctor' => 211,
+			'ctor' => 213,
 			'basic_type' => 36,
 			'nconsttype' => 25,
 			'template' => 13,
 			'looks_like_function' => 51,
 			'virtual' => 190,
-			'perc_name' => 209,
+			'perc_name' => 211,
 			'_vmethod' => 193,
-			'dtor' => 212,
-			'vmethod' => 210,
+			'dtor' => 214,
+			'vmethod' => 212,
 			'type' => 20
 		}
 	},
 	{#State 173
-		DEFAULT => -45
+		DEFAULT => -44
 	},
 	{#State 174
-		DEFAULT => -52
-	},
-	{#State 175
 		DEFAULT => -51
 	},
+	{#State 175
+		DEFAULT => -50
+	},
 	{#State 176
-		ACTIONS => {
-			'COLON' => 213
-		}
-	},
-	{#State 177
-		DEFAULT => -47
-	},
-	{#State 178
-		DEFAULT => -53
-	},
-	{#State 179
-		ACTIONS => {
-			'ID' => 214
-		}
-	},
-	{#State 180
 		ACTIONS => {
 			'COLON' => 215
 		}
 	},
+	{#State 177
+		DEFAULT => -46
+	},
+	{#State 178
+		DEFAULT => -52
+	},
+	{#State 179
+		ACTIONS => {
+			'ID' => 216
+		}
+	},
+	{#State 180
+		ACTIONS => {
+			'COLON' => 217
+		}
+	},
 	{#State 181
-		DEFAULT => -54
+		DEFAULT => -53
 	},
 	{#State 182
 		ACTIONS => {
-			'SEMICOLON' => 216
+			'SEMICOLON' => 218
 		}
 	},
 	{#State 183
 		ACTIONS => {
 			'DCOLON' => 63,
-			'OPPAR' => 217
+			'OPPAR' => 219
 		},
-		DEFAULT => -110,
+		DEFAULT => -112,
 		GOTOS => {
 			'class_suffix' => 62
 		}
 	},
 	{#State 184
-		DEFAULT => -57
+		DEFAULT => -56
 	},
 	{#State 185
-		DEFAULT => -58
+		DEFAULT => -57
 	},
 	{#State 186
-		DEFAULT => -46
+		DEFAULT => -45
 	},
 	{#State 187
-		DEFAULT => -42
+		DEFAULT => -41
 	},
 	{#State 188
-		DEFAULT => -43
+		DEFAULT => -42
 	},
 	{#State 189
-		DEFAULT => -60
+		DEFAULT => -59
 	},
 	{#State 190
 		ACTIONS => {
@@ -1746,75 +1748,91 @@ sub new {
 			'basic_type' => 36,
 			'nconsttype' => 25,
 			'template' => 13,
-			'looks_like_function' => 218,
+			'looks_like_function' => 220,
 			'type' => 20
 		}
 	},
 	{#State 191
-		DEFAULT => -30
+		DEFAULT => -29
 	},
 	{#State 192
-		DEFAULT => -70,
+		DEFAULT => -69,
 		GOTOS => {
-			'function_metadata' => 219
+			'function_metadata' => 221
 		}
 	},
 	{#State 193
-		DEFAULT => -73
+		DEFAULT => -72
 	},
 	{#State 194
-		DEFAULT => -44
+		DEFAULT => -43
 	},
 	{#State 195
 		ACTIONS => {
-			'CLCURLY' => 220
+			'CLCURLY' => 222
 		}
 	},
 	{#State 196
 		ACTIONS => {
-			'OPPAR' => 221
+			'OPPAR' => 223
 		},
-		DEFAULT => -129
+		DEFAULT => -131
 	},
 	{#State 197
 		DEFAULT => -125
 	},
 	{#State 198
-		DEFAULT => -123
-	},
-	{#State 199
-		DEFAULT => -128
-	},
-	{#State 200
 		DEFAULT => -127
 	},
-	{#State 201
+	{#State 199
 		ACTIONS => {
-			'INTEGER' => 222
-		}
+			'AMP' => 224,
+			'PIPE' => 225
+		},
+		DEFAULT => -136
+	},
+	{#State 200
+		DEFAULT => -130
+	},
+	{#State 201
+		DEFAULT => -129
 	},
 	{#State 202
 		ACTIONS => {
-			'OPCURLY' => 223
+			'INTEGER' => 226
 		}
 	},
 	{#State 203
-		DEFAULT => -113
+		ACTIONS => {
+			'OPCURLY' => 227
+		}
 	},
 	{#State 204
-		DEFAULT => -134
+		DEFAULT => -115
 	},
 	{#State 205
 		ACTIONS => {
-			'OPSPECIAL' => 28,
-			'SEMICOLON' => 225
+			'p_any' => 228
 		},
 		GOTOS => {
-			'special_block' => 224,
-			'special_block_start' => 30
+			'perc_any_arg' => 229,
+			'perc_any_args' => 230
 		}
 	},
 	{#State 206
+		DEFAULT => -139
+	},
+	{#State 207
+		ACTIONS => {
+			'OPSPECIAL' => 28,
+			'SEMICOLON' => 232
+		},
+		GOTOS => {
+			'special_block' => 231,
+			'special_block_start' => 30
+		}
+	},
+	{#State 208
 		ACTIONS => {
 			'ID' => 23,
 			"short" => 15,
@@ -1834,52 +1852,52 @@ sub new {
 			'type' => 20
 		}
 	},
-	{#State 207
-		DEFAULT => -72
-	},
-	{#State 208
-		DEFAULT => -48
-	},
 	{#State 209
+		DEFAULT => -71
+	},
+	{#State 210
+		DEFAULT => -47
+	},
+	{#State 211
 		ACTIONS => {
-			'ID' => 226,
+			'ID' => 233,
 			'TILDE' => 179,
 			'p_name' => 17,
 			"virtual" => 184
 		},
 		GOTOS => {
-			'perc_name' => 209,
-			'ctor' => 211,
+			'perc_name' => 211,
+			'ctor' => 213,
 			'_vmethod' => 193,
-			'dtor' => 212,
-			'vmethod' => 210,
+			'dtor' => 214,
+			'vmethod' => 212,
 			'virtual' => 190
 		}
 	},
-	{#State 210
-		DEFAULT => -74
-	},
-	{#State 211
-		DEFAULT => -66
-	},
 	{#State 212
-		DEFAULT => -68
+		DEFAULT => -73
 	},
 	{#State 213
-		DEFAULT => -50
+		DEFAULT => -65
 	},
 	{#State 214
-		ACTIONS => {
-			'OPPAR' => 227
-		}
+		DEFAULT => -67
 	},
 	{#State 215
 		DEFAULT => -49
 	},
 	{#State 216
-		DEFAULT => -28
+		ACTIONS => {
+			'OPPAR' => 234
+		}
 	},
 	{#State 217
+		DEFAULT => -48
+	},
+	{#State 218
+		DEFAULT => -27
+	},
+	{#State 219
 		ACTIONS => {
 			'ID' => 23,
 			"short" => 15,
@@ -1889,35 +1907,35 @@ sub new {
 			"int" => 34,
 			"char" => 22
 		},
-		DEFAULT => -121,
+		DEFAULT => -123,
 		GOTOS => {
 			'type_name' => 12,
 			'class_name' => 1,
 			'basic_type' => 36,
 			'nconsttype' => 25,
 			'template' => 13,
-			'arg_list' => 228,
+			'arg_list' => 235,
 			'argument' => 127,
 			'type' => 125
 		}
 	},
-	{#State 218
+	{#State 220
 		ACTIONS => {
-			'EQUAL' => 229
+			'EQUAL' => 236
 		},
-		DEFAULT => -70,
+		DEFAULT => -69,
 		GOTOS => {
-			'function_metadata' => 230
+			'function_metadata' => 237
 		}
 	},
-	{#State 219
+	{#State 221
 		ACTIONS => {
 			'p_code' => 106,
 			'p_cleanup' => 102,
 			'p_catch' => 109,
 			'p_postcall' => 104
 		},
-		DEFAULT => -71,
+		DEFAULT => -70,
 		GOTOS => {
 			'perc_postcall' => 105,
 			'perc_code' => 101,
@@ -1926,60 +1944,249 @@ sub new {
 			'_function_metadata' => 108
 		}
 	},
-	{#State 220
-		DEFAULT => -122
-	},
-	{#State 221
-		ACTIONS => {
-			'ID' => 23,
-			'INTEGER' => 197,
-			'QUOTED_STRING' => 199,
-			'DASH' => 201,
-			'FLOAT' => 200
-		},
-		DEFAULT => -133,
-		GOTOS => {
-			'class_name' => 196,
-			'value_list' => 231,
-			'value' => 232
-		}
-	},
 	{#State 222
-		DEFAULT => -126
+		DEFAULT => -124
 	},
 	{#State 223
 		ACTIONS => {
-			'ID' => 233
+			'ID' => 23,
+			'INTEGER' => 198,
+			'QUOTED_STRING' => 200,
+			'DASH' => 202,
+			'FLOAT' => 201
+		},
+		DEFAULT => -135,
+		GOTOS => {
+			'class_name' => 196,
+			'value_list' => 238,
+			'value' => 239
 		}
 	},
 	{#State 224
-		DEFAULT => -135
+		ACTIONS => {
+			'ID' => 23,
+			'INTEGER' => 198,
+			'QUOTED_STRING' => 200,
+			'DASH' => 202,
+			'FLOAT' => 201
+		},
+		GOTOS => {
+			'class_name' => 196,
+			'value' => 240
+		}
 	},
 	{#State 225
-		DEFAULT => -14
+		ACTIONS => {
+			'ID' => 23,
+			'INTEGER' => 198,
+			'QUOTED_STRING' => 200,
+			'DASH' => 202,
+			'FLOAT' => 201
+		},
+		GOTOS => {
+			'class_name' => 196,
+			'value' => 241
+		}
 	},
 	{#State 226
-		ACTIONS => {
-			'OPPAR' => 217
-		}
+		DEFAULT => -128
 	},
 	{#State 227
 		ACTIONS => {
-			'CLPAR' => 234
+			'ID' => 242
 		}
 	},
 	{#State 228
-		ACTIONS => {
-			'CLPAR' => 235,
-			'COMMA' => 152
+		DEFAULT => -19,
+		GOTOS => {
+			'mixed_blocks' => 243
 		}
 	},
 	{#State 229
-		ACTIONS => {
-			'INTEGER' => 236
-		}
+		DEFAULT => -90
 	},
 	{#State 230
+		ACTIONS => {
+			'p_any' => 228,
+			'CLCURLY' => 245
+		},
+		GOTOS => {
+			'perc_any_arg' => 244
+		}
+	},
+	{#State 231
+		DEFAULT => -140
+	},
+	{#State 232
+		DEFAULT => -14
+	},
+	{#State 233
+		ACTIONS => {
+			'OPPAR' => 219
+		}
+	},
+	{#State 234
+		ACTIONS => {
+			'CLPAR' => 246
+		}
+	},
+	{#State 235
+		ACTIONS => {
+			'CLPAR' => 247,
+			'COMMA' => 152
+		}
+	},
+	{#State 236
+		ACTIONS => {
+			'INTEGER' => 248
+		}
+	},
+	{#State 237
+		ACTIONS => {
+			'p_code' => 106,
+			'p_cleanup' => 102,
+			'p_catch' => 109,
+			'p_postcall' => 104
+		},
+		DEFAULT => -74,
+		GOTOS => {
+			'perc_postcall' => 105,
+			'perc_code' => 101,
+			'perc_cleanup' => 107,
+			'perc_catch' => 103,
+			'_function_metadata' => 108
+		}
+	},
+	{#State 238
+		ACTIONS => {
+			'CLPAR' => 249,
+			'COMMA' => 250
+		}
+	},
+	{#State 239
+		DEFAULT => -133
+	},
+	{#State 240
+		DEFAULT => -137
+	},
+	{#State 241
+		DEFAULT => -138
+	},
+	{#State 242
+		ACTIONS => {
+			'CLCURLY' => 251
+		}
+	},
+	{#State 243
+		ACTIONS => {
+			'OPCURLY' => 252,
+			'OPSPECIAL' => 28,
+			'SEMICOLON' => 254
+		},
+		GOTOS => {
+			'simple_block' => 255,
+			'special_block' => 253,
+			'special_block_start' => 30
+		}
+	},
+	{#State 244
+		DEFAULT => -91
+	},
+	{#State 245
+		ACTIONS => {
+			'SEMICOLON' => 256
+		}
+	},
+	{#State 246
+		DEFAULT => -69,
+		GOTOS => {
+			'function_metadata' => 257
+		}
+	},
+	{#State 247
+		DEFAULT => -69,
+		GOTOS => {
+			'function_metadata' => 258
+		}
+	},
+	{#State 248
+		DEFAULT => -69,
+		GOTOS => {
+			'function_metadata' => 259
+		}
+	},
+	{#State 249
+		DEFAULT => -132
+	},
+	{#State 250
+		ACTIONS => {
+			'ID' => 23,
+			'INTEGER' => 198,
+			'QUOTED_STRING' => 200,
+			'DASH' => 202,
+			'FLOAT' => 201
+		},
+		GOTOS => {
+			'class_name' => 196,
+			'value' => 260
+		}
+	},
+	{#State 251
+		DEFAULT => -19,
+		GOTOS => {
+			'mixed_blocks' => 261
+		}
+	},
+	{#State 252
+		ACTIONS => {
+			'ID' => 262
+		}
+	},
+	{#State 253
+		DEFAULT => -17
+	},
+	{#State 254
+		DEFAULT => -92
+	},
+	{#State 255
+		DEFAULT => -18
+	},
+	{#State 256
+		DEFAULT => -15
+	},
+	{#State 257
+		ACTIONS => {
+			'p_code' => 106,
+			'p_cleanup' => 102,
+			'p_catch' => 109,
+			'p_postcall' => 104
+		},
+		DEFAULT => -66,
+		GOTOS => {
+			'perc_postcall' => 105,
+			'perc_code' => 101,
+			'perc_cleanup' => 107,
+			'perc_catch' => 103,
+			'_function_metadata' => 108
+		}
+	},
+	{#State 258
+		ACTIONS => {
+			'p_code' => 106,
+			'p_cleanup' => 102,
+			'p_catch' => 109,
+			'p_postcall' => 104
+		},
+		DEFAULT => -64,
+		GOTOS => {
+			'perc_postcall' => 105,
+			'perc_code' => 101,
+			'perc_cleanup' => 107,
+			'perc_catch' => 103,
+			'_function_metadata' => 108
+		}
+	},
+	{#State 259
 		ACTIONS => {
 			'p_code' => 106,
 			'p_cleanup' => 102,
@@ -1995,157 +2202,31 @@ sub new {
 			'_function_metadata' => 108
 		}
 	},
-	{#State 231
+	{#State 260
+		DEFAULT => -134
+	},
+	{#State 261
 		ACTIONS => {
-			'CLPAR' => 237,
-			'COMMA' => 238
-		}
-	},
-	{#State 232
-		DEFAULT => -131
-	},
-	{#State 233
-		ACTIONS => {
-			'CLCURLY' => 239
-		}
-	},
-	{#State 234
-		DEFAULT => -70,
-		GOTOS => {
-			'function_metadata' => 240
-		}
-	},
-	{#State 235
-		DEFAULT => -70,
-		GOTOS => {
-			'function_metadata' => 241
-		}
-	},
-	{#State 236
-		DEFAULT => -70,
-		GOTOS => {
-			'function_metadata' => 242
-		}
-	},
-	{#State 237
-		DEFAULT => -130
-	},
-	{#State 238
-		ACTIONS => {
-			'ID' => 23,
-			'INTEGER' => 197,
-			'QUOTED_STRING' => 199,
-			'DASH' => 201,
-			'FLOAT' => 200
-		},
-		GOTOS => {
-			'class_name' => 196,
-			'value' => 243
-		}
-	},
-	{#State 239
-		ACTIONS => {
-			'OPCURLY' => 245,
-			'OPSPECIAL' => 28
-		},
-		DEFAULT => -20,
-		GOTOS => {
-			'simple_block' => 247,
-			'mixed_blocks' => 244,
-			'special_block' => 246,
-			'special_block_start' => 30
-		}
-	},
-	{#State 240
-		ACTIONS => {
-			'p_code' => 106,
-			'p_cleanup' => 102,
-			'p_catch' => 109,
-			'p_postcall' => 104
-		},
-		DEFAULT => -67,
-		GOTOS => {
-			'perc_postcall' => 105,
-			'perc_code' => 101,
-			'perc_cleanup' => 107,
-			'perc_catch' => 103,
-			'_function_metadata' => 108
-		}
-	},
-	{#State 241
-		ACTIONS => {
-			'p_code' => 106,
-			'p_cleanup' => 102,
-			'p_catch' => 109,
-			'p_postcall' => 104
-		},
-		DEFAULT => -65,
-		GOTOS => {
-			'perc_postcall' => 105,
-			'perc_code' => 101,
-			'perc_cleanup' => 107,
-			'perc_catch' => 103,
-			'_function_metadata' => 108
-		}
-	},
-	{#State 242
-		ACTIONS => {
-			'p_code' => 106,
-			'p_cleanup' => 102,
-			'p_catch' => 109,
-			'p_postcall' => 104
-		},
-		DEFAULT => -76,
-		GOTOS => {
-			'perc_postcall' => 105,
-			'perc_code' => 101,
-			'perc_cleanup' => 107,
-			'perc_catch' => 103,
-			'_function_metadata' => 108
-		}
-	},
-	{#State 243
-		DEFAULT => -132
-	},
-	{#State 244
-		ACTIONS => {
-			'OPCURLY' => 245,
+			'OPCURLY' => 252,
 			'OPSPECIAL' => 28,
-			'SEMICOLON' => 249
+			'SEMICOLON' => 263
 		},
 		GOTOS => {
-			'simple_block' => 250,
-			'special_block' => 248,
+			'simple_block' => 255,
+			'special_block' => 253,
 			'special_block_start' => 30
 		}
 	},
-	{#State 245
+	{#State 262
 		ACTIONS => {
-			'ID' => 251
+			'CLCURLY' => 264
 		}
 	},
-	{#State 246
+	{#State 263
 		DEFAULT => -16
 	},
-	{#State 247
-		DEFAULT => -17
-	},
-	{#State 248
-		DEFAULT => -18
-	},
-	{#State 249
-		DEFAULT => -15
-	},
-	{#State 250
-		DEFAULT => -19
-	},
-	{#State 251
-		ACTIONS => {
-			'CLCURLY' => 252
-		}
-	},
-	{#State 252
-		DEFAULT => -21
+	{#State 264
+		DEFAULT => -20
 	}
 ],
                                   yyrules  =>
@@ -2236,9 +2317,25 @@ sub
                       undef }
 	],
 	[#Rule 15
+		 'typemap', 11,
+sub
+#line 53 "XSP.yp"
+{ my $package = "ExtUtils::XSpp::Typemap::" . $_[6];
+                      my $type = $_[3];
+                      # this assumes that there will be at most one named
+                      # block for each directive inside the typemap
+                      for( my $i = 1; $i <= $#{$_[9]}; $i += 2 ) {
+                          $_[9][$i] = join "\n", @{$_[9][$i][0]}
+                              if ref( $_[9][$i] ) && ref( $_[9][$i][0] );
+                      }
+                      my $tm = $package->new( type => $type, @{$_[9]} );
+                      ExtUtils::XSpp::Typemap::add_typemap_for_type( $type, $tm );
+                      undef }
+	],
+	[#Rule 16
 		 'exceptionmap', 12,
 sub
-#line 55 "XSP.yp"
+#line 69 "XSP.yp"
 { my $package = "ExtUtils::XSpp::Exception::" . $_[9];
                       my $type = make_type($_[6]); my $c = 0;
                       my %args = map { "arg" . ++$c => $_ }
@@ -2248,153 +2345,147 @@ sub
                       ExtUtils::XSpp::Exception->add_exception( $e );
                       undef }
 	],
-	[#Rule 16
-		 'mixed_blocks', 1,
-sub
-#line 65 "XSP.yp"
-{ [ $_[1] ] }
-	],
 	[#Rule 17
-		 'mixed_blocks', 1,
+		 'mixed_blocks', 2,
 sub
-#line 67 "XSP.yp"
-{ [ [$_[1]] ] }
+#line 79 "XSP.yp"
+{ [ @{$_[1]}, $_[2] ] }
 	],
 	[#Rule 18
 		 'mixed_blocks', 2,
 sub
-#line 69 "XSP.yp"
-{ [ @{$_[1]}, $_[2] ] }
+#line 81 "XSP.yp"
+{ [ @{$_[1]}, [ $_[2] ] ] }
 	],
 	[#Rule 19
-		 'mixed_blocks', 2,
+		 'mixed_blocks', 0,
 sub
-#line 71 "XSP.yp"
-{ [ @{$_[1]}, $_[2] ] }
+#line 82 "XSP.yp"
+{ [] }
 	],
 	[#Rule 20
-		 'mixed_blocks', 0, undef
-	],
-	[#Rule 21
 		 'simple_block', 3,
 sub
-#line 75 "XSP.yp"
+#line 85 "XSP.yp"
 { $_[2] }
+	],
+	[#Rule 21
+		 'raw', 1,
+sub
+#line 87 "XSP.yp"
+{ add_data_raw( $_[0], [ $_[1] ] ) }
 	],
 	[#Rule 22
 		 'raw', 1,
 sub
-#line 77 "XSP.yp"
-{ add_data_raw( $_[0], [ $_[1] ] ) }
+#line 88 "XSP.yp"
+{ add_data_comment( $_[0], $_[1] ) }
 	],
 	[#Rule 23
 		 'raw', 1,
 sub
-#line 78 "XSP.yp"
-{ add_data_comment( $_[0], $_[1] ) }
+#line 89 "XSP.yp"
+{ add_data_raw( $_[0], [ @{$_[1]} ] ) }
 	],
 	[#Rule 24
-		 'raw', 1,
-sub
-#line 79 "XSP.yp"
-{ add_data_raw( $_[0], [ @{$_[1]} ] ) }
+		 'class', 2, undef
 	],
 	[#Rule 25
 		 'class', 2, undef
 	],
 	[#Rule 26
-		 'class', 2, undef
-	],
-	[#Rule 27
 		 'function', 2, undef
 	],
-	[#Rule 28
+	[#Rule 27
 		 'method', 2, undef
 	],
-	[#Rule 29
+	[#Rule 28
 		 'decorate_class', 2,
 sub
-#line 86 "XSP.yp"
+#line 96 "XSP.yp"
 { $_[2]->set_perl_name( $_[1] ); $_[2] }
 	],
-	[#Rule 30
+	[#Rule 29
 		 'class_decl', 7,
 sub
-#line 89 "XSP.yp"
+#line 99 "XSP.yp"
 { create_class( $_[0], $_[2], $_[3], $_[4], $_[6] ) }
 	],
-	[#Rule 31
+	[#Rule 30
 		 'base_classes', 2,
 sub
-#line 92 "XSP.yp"
+#line 102 "XSP.yp"
 { [ $_[2] ] }
 	],
-	[#Rule 32
+	[#Rule 31
 		 'base_classes', 3,
 sub
-#line 93 "XSP.yp"
+#line 103 "XSP.yp"
 { push @{$_[1]}, $_[3] if $_[3]; $_[1] }
 	],
-	[#Rule 33
+	[#Rule 32
 		 'base_classes', 0, undef
 	],
+	[#Rule 33
+		 'base_class', 2,
+sub
+#line 107 "XSP.yp"
+{ $_[2] }
+	],
 	[#Rule 34
 		 'base_class', 2,
 sub
-#line 97 "XSP.yp"
+#line 108 "XSP.yp"
 { $_[2] }
 	],
 	[#Rule 35
 		 'base_class', 2,
 sub
-#line 98 "XSP.yp"
+#line 109 "XSP.yp"
 { $_[2] }
 	],
 	[#Rule 36
-		 'base_class', 2,
-sub
-#line 99 "XSP.yp"
-{ $_[2] }
-	],
-	[#Rule 37
 		 'class_name_rename', 1,
 sub
-#line 103 "XSP.yp"
+#line 113 "XSP.yp"
 { create_class( $_[0], $_[1], [], [] ) }
 	],
-	[#Rule 38
+	[#Rule 37
 		 'class_name_rename', 2,
 sub
-#line 104 "XSP.yp"
+#line 114 "XSP.yp"
 { my $klass = create_class( $_[0], $_[2], [], [] );
                              $klass->set_perl_name( $_[1] );
                              $klass
                              }
 	],
-	[#Rule 39
+	[#Rule 38
 		 'class_metadata', 2,
 sub
-#line 110 "XSP.yp"
+#line 120 "XSP.yp"
 { [ @{$_[1]}, @{$_[2]} ] }
 	],
-	[#Rule 40
+	[#Rule 39
 		 'class_metadata', 0,
 sub
-#line 111 "XSP.yp"
+#line 121 "XSP.yp"
+{ [] }
+	],
+	[#Rule 40
+		 'class_body_list', 0,
+sub
+#line 125 "XSP.yp"
 { [] }
 	],
 	[#Rule 41
-		 'class_body_list', 0,
-sub
-#line 115 "XSP.yp"
-{ [] }
-	],
-	[#Rule 42
 		 'class_body_list', 2,
 sub
-#line 117 "XSP.yp"
+#line 127 "XSP.yp"
 { push @{$_[1]}, $_[2] if $_[2]; $_[1] }
 	],
+	[#Rule 42
+		 'class_body_element', 1, undef
+	],
 	[#Rule 43
 		 'class_body_element', 1, undef
 	],
@@ -2408,25 +2499,25 @@ sub
 		 'class_body_element', 1, undef
 	],
 	[#Rule 47
-		 'class_body_element', 1, undef
+		 'access_specifier', 2,
+sub
+#line 133 "XSP.yp"
+{ ExtUtils::XSpp::Node::Access->new( access => $_[1] ) }
 	],
 	[#Rule 48
 		 'access_specifier', 2,
 sub
-#line 123 "XSP.yp"
+#line 134 "XSP.yp"
 { ExtUtils::XSpp::Node::Access->new( access => $_[1] ) }
 	],
 	[#Rule 49
 		 'access_specifier', 2,
 sub
-#line 124 "XSP.yp"
+#line 135 "XSP.yp"
 { ExtUtils::XSpp::Node::Access->new( access => $_[1] ) }
 	],
 	[#Rule 50
-		 'access_specifier', 2,
-sub
-#line 125 "XSP.yp"
-{ ExtUtils::XSpp::Node::Access->new( access => $_[1] ) }
+		 'method_decl', 1, undef
 	],
 	[#Rule 51
 		 'method_decl', 1, undef
@@ -2438,39 +2529,36 @@ sub
 		 'method_decl', 1, undef
 	],
 	[#Rule 54
-		 'method_decl', 1, undef
-	],
-	[#Rule 55
 		 'const', 1,
 sub
-#line 130 "XSP.yp"
+#line 140 "XSP.yp"
 { 1 }
 	],
-	[#Rule 56
+	[#Rule 55
 		 'const', 0,
 sub
-#line 131 "XSP.yp"
+#line 141 "XSP.yp"
 { 0 }
 	],
-	[#Rule 57
+	[#Rule 56
 		 'virtual', 1, undef
 	],
+	[#Rule 57
+		 'static', 1, undef
+	],
 	[#Rule 58
 		 'static', 1, undef
 	],
 	[#Rule 59
-		 'static', 1, undef
-	],
-	[#Rule 60
 		 'static', 1,
 sub
-#line 137 "XSP.yp"
+#line 147 "XSP.yp"
 { 'package_static' }
 	],
-	[#Rule 61
+	[#Rule 60
 		 'looks_like_function', 6,
 sub
-#line 142 "XSP.yp"
+#line 152 "XSP.yp"
 {
               return { ret_type  => $_[1],
                        name      => $_[2],
@@ -2479,19 +2567,19 @@ sub
                        };
           }
 	],
-	[#Rule 62
+	[#Rule 61
 		 'looks_like_renamed_function', 1, undef
 	],
-	[#Rule 63
+	[#Rule 62
 		 'looks_like_renamed_function', 2,
 sub
-#line 153 "XSP.yp"
+#line 163 "XSP.yp"
 { $_[2]->{perl_name} = $_[1]; $_[2] }
 	],
-	[#Rule 64
+	[#Rule 63
 		 'function_decl', 2,
 sub
-#line 156 "XSP.yp"
+#line 166 "XSP.yp"
 { add_data_function( $_[0],
                                          name      => $_[1]->{name},
                                          perl_name => $_[1]->{perl_name},
@@ -2499,50 +2587,50 @@ sub
                                          arguments => $_[1]->{arguments},
                                          @{$_[2]} ) }
 	],
-	[#Rule 65
+	[#Rule 64
 		 'ctor', 5,
 sub
-#line 164 "XSP.yp"
+#line 174 "XSP.yp"
 { add_data_ctor( $_[0], name      => $_[1],
                                             arguments => $_[3],
                                             @{ $_[5] } ) }
 	],
-	[#Rule 66
+	[#Rule 65
 		 'ctor', 2,
 sub
-#line 167 "XSP.yp"
+#line 177 "XSP.yp"
 { $_[2]->set_perl_name( $_[1] ); $_[2] }
 	],
-	[#Rule 67
+	[#Rule 66
 		 'dtor', 5,
 sub
-#line 170 "XSP.yp"
+#line 180 "XSP.yp"
 { add_data_dtor( $_[0], name  => $_[2],
                                             @{ $_[5] },
                                       ) }
 	],
-	[#Rule 68
+	[#Rule 67
 		 'dtor', 2,
 sub
-#line 173 "XSP.yp"
+#line 183 "XSP.yp"
 { $_[2]->set_perl_name( $_[1] ); $_[2] }
 	],
-	[#Rule 69
+	[#Rule 68
 		 'function_metadata', 2,
 sub
-#line 175 "XSP.yp"
+#line 185 "XSP.yp"
 { [ @{$_[1]}, @{$_[2]} ] }
 	],
-	[#Rule 70
+	[#Rule 69
 		 'function_metadata', 0,
 sub
-#line 176 "XSP.yp"
+#line 186 "XSP.yp"
 { [] }
 	],
-	[#Rule 71
+	[#Rule 70
 		 'nmethod', 2,
 sub
-#line 181 "XSP.yp"
+#line 191 "XSP.yp"
 { my $m = add_data_method
                         ( $_[0],
                           name      => $_[1]->{name},
@@ -2555,25 +2643,25 @@ sub
             $m
           }
 	],
-	[#Rule 72
+	[#Rule 71
 		 'nmethod', 2,
 sub
-#line 193 "XSP.yp"
+#line 203 "XSP.yp"
 { $_[2]->set_static( $_[1] ); $_[2] }
 	],
-	[#Rule 73
+	[#Rule 72
 		 'vmethod', 1, undef
 	],
-	[#Rule 74
+	[#Rule 73
 		 'vmethod', 2,
 sub
-#line 198 "XSP.yp"
+#line 208 "XSP.yp"
 { $_[2]->set_perl_name( $_[1] ); $_[2] }
 	],
-	[#Rule 75
+	[#Rule 74
 		 '_vmethod', 3,
 sub
-#line 203 "XSP.yp"
+#line 213 "XSP.yp"
 { my $m = add_data_method
                         ( $_[0],
                           name      => $_[2]->{name},
@@ -2587,10 +2675,10 @@ sub
             $m
           }
 	],
-	[#Rule 76
+	[#Rule 75
 		 '_vmethod', 5,
 sub
-#line 216 "XSP.yp"
+#line 226 "XSP.yp"
 { my $m = add_data_method
                         ( $_[0],
                           name      => $_[2]->{name},
@@ -2605,6 +2693,9 @@ sub
             $m
           }
 	],
+	[#Rule 76
+		 '_function_metadata', 1, undef
+	],
 	[#Rule 77
 		 '_function_metadata', 1, undef
 	],
@@ -2615,121 +2706,130 @@ sub
 		 '_function_metadata', 1, undef
 	],
 	[#Rule 80
-		 '_function_metadata', 1, undef
-	],
-	[#Rule 81
 		 'perc_name', 4,
 sub
-#line 237 "XSP.yp"
+#line 247 "XSP.yp"
+{ $_[3] }
+	],
+	[#Rule 81
+		 'perc_package', 4,
+sub
+#line 248 "XSP.yp"
 { $_[3] }
 	],
 	[#Rule 82
-		 'perc_package', 4,
+		 'perc_module', 4,
 sub
-#line 238 "XSP.yp"
+#line 249 "XSP.yp"
 { $_[3] }
 	],
 	[#Rule 83
-		 'perc_module', 4,
+		 'perc_file', 4,
 sub
-#line 239 "XSP.yp"
+#line 250 "XSP.yp"
 { $_[3] }
 	],
 	[#Rule 84
-		 'perc_file', 4,
+		 'perc_loadplugin', 4,
 sub
-#line 240 "XSP.yp"
+#line 251 "XSP.yp"
 { $_[3] }
 	],
 	[#Rule 85
-		 'perc_loadplugin', 4,
+		 'perc_include', 4,
 sub
-#line 241 "XSP.yp"
+#line 252 "XSP.yp"
 { $_[3] }
 	],
 	[#Rule 86
-		 'perc_include', 4,
-sub
-#line 242 "XSP.yp"
-{ $_[3] }
-	],
-	[#Rule 87
 		 'perc_code', 2,
 sub
-#line 243 "XSP.yp"
+#line 253 "XSP.yp"
 { [ code => $_[2] ] }
 	],
-	[#Rule 88
+	[#Rule 87
 		 'perc_cleanup', 2,
 sub
-#line 244 "XSP.yp"
+#line 254 "XSP.yp"
 { [ cleanup => $_[2] ] }
 	],
-	[#Rule 89
+	[#Rule 88
 		 'perc_postcall', 2,
 sub
-#line 245 "XSP.yp"
+#line 255 "XSP.yp"
 { [ postcall => $_[2] ] }
 	],
-	[#Rule 90
+	[#Rule 89
 		 'perc_catch', 4,
 sub
-#line 246 "XSP.yp"
+#line 256 "XSP.yp"
 { [ map {(catch => $_)} @{$_[3]} ] }
 	],
-	[#Rule 91
-		 'type', 2,
+	[#Rule 90
+		 'perc_any_args', 1,
 sub
-#line 249 "XSP.yp"
-{ make_const( $_[2] ) }
+#line 259 "XSP.yp"
+{ $_[1] }
+	],
+	[#Rule 91
+		 'perc_any_args', 2,
+sub
+#line 260 "XSP.yp"
+{ [ @{$_[1]}, @{$_[2]} ] }
 	],
 	[#Rule 92
-		 'type', 1, undef
-	],
-	[#Rule 93
-		 'nconsttype', 2,
-sub
-#line 254 "XSP.yp"
-{ make_ptr( $_[1] ) }
-	],
-	[#Rule 94
-		 'nconsttype', 2,
-sub
-#line 255 "XSP.yp"
-{ make_ref( $_[1] ) }
-	],
-	[#Rule 95
-		 'nconsttype', 1,
-sub
-#line 256 "XSP.yp"
-{ make_type( $_[1] ) }
-	],
-	[#Rule 96
-		 'nconsttype', 1, undef
-	],
-	[#Rule 97
-		 'type_name', 1, undef
-	],
-	[#Rule 98
-		 'type_name', 1, undef
-	],
-	[#Rule 99
-		 'type_name', 1,
-sub
-#line 263 "XSP.yp"
-{ 'unsigned int' }
-	],
-	[#Rule 100
-		 'type_name', 2,
+		 'perc_any_arg', 3,
 sub
 #line 264 "XSP.yp"
-{ 'unsigned' . ' ' . $_[2] }
+{ [ $_[1] => $_[2] ] }
+	],
+	[#Rule 93
+		 'type', 2,
+sub
+#line 268 "XSP.yp"
+{ make_const( $_[2] ) }
+	],
+	[#Rule 94
+		 'type', 1, undef
+	],
+	[#Rule 95
+		 'nconsttype', 2,
+sub
+#line 273 "XSP.yp"
+{ make_ptr( $_[1] ) }
+	],
+	[#Rule 96
+		 'nconsttype', 2,
+sub
+#line 274 "XSP.yp"
+{ make_ref( $_[1] ) }
+	],
+	[#Rule 97
+		 'nconsttype', 1,
+sub
+#line 275 "XSP.yp"
+{ make_type( $_[1] ) }
+	],
+	[#Rule 98
+		 'nconsttype', 1, undef
+	],
+	[#Rule 99
+		 'type_name', 1, undef
+	],
+	[#Rule 100
+		 'type_name', 1, undef
 	],
 	[#Rule 101
-		 'basic_type', 1, undef
+		 'type_name', 1,
+sub
+#line 282 "XSP.yp"
+{ 'unsigned int' }
 	],
 	[#Rule 102
-		 'basic_type', 1, undef
+		 'type_name', 2,
+sub
+#line 283 "XSP.yp"
+{ 'unsigned' . ' ' . $_[2] }
 	],
 	[#Rule 103
 		 'basic_type', 1, undef
@@ -2738,201 +2838,222 @@ sub
 		 'basic_type', 1, undef
 	],
 	[#Rule 105
-		 'basic_type', 2, undef
+		 'basic_type', 1, undef
 	],
 	[#Rule 106
-		 'basic_type', 2, undef
+		 'basic_type', 1, undef
 	],
 	[#Rule 107
-		 'template', 4,
-sub
-#line 270 "XSP.yp"
-{ make_template( $_[1], $_[3] ) }
+		 'basic_type', 2, undef
 	],
 	[#Rule 108
-		 'type_list', 1,
-sub
-#line 274 "XSP.yp"
-{ [ $_[1] ] }
+		 'basic_type', 2, undef
 	],
 	[#Rule 109
-		 'type_list', 3,
-sub
-#line 275 "XSP.yp"
-{ push @{$_[1]}, $_[3]; $_[1] }
-	],
-	[#Rule 110
-		 'class_name', 1, undef
-	],
-	[#Rule 111
-		 'class_name', 2,
-sub
-#line 279 "XSP.yp"
-{ $_[1] . '::' . $_[2] }
-	],
-	[#Rule 112
-		 'class_name_list', 1,
-sub
-#line 282 "XSP.yp"
-{ [ $_[1] ] }
-	],
-	[#Rule 113
-		 'class_name_list', 3,
-sub
-#line 283 "XSP.yp"
-{ push @{$_[1]}, $_[3]; $_[1] }
-	],
-	[#Rule 114
-		 'class_suffix', 2,
-sub
-#line 286 "XSP.yp"
-{ $_[2] }
-	],
-	[#Rule 115
-		 'class_suffix', 3,
-sub
-#line 287 "XSP.yp"
-{ $_[1] . '::' . $_[3] }
-	],
-	[#Rule 116
-		 'file_name', 1,
+		 'template', 4,
 sub
 #line 289 "XSP.yp"
-{ '-' }
+{ make_template( $_[1], $_[3] ) }
 	],
-	[#Rule 117
-		 'file_name', 3,
-sub
-#line 290 "XSP.yp"
-{ $_[1] . '.' . $_[3] }
-	],
-	[#Rule 118
-		 'file_name', 3,
-sub
-#line 291 "XSP.yp"
-{ $_[1] . '/' . $_[3] }
-	],
-	[#Rule 119
-		 'arg_list', 1,
+	[#Rule 110
+		 'type_list', 1,
 sub
 #line 293 "XSP.yp"
 { [ $_[1] ] }
 	],
-	[#Rule 120
-		 'arg_list', 3,
+	[#Rule 111
+		 'type_list', 3,
 sub
 #line 294 "XSP.yp"
 { push @{$_[1]}, $_[3]; $_[1] }
 	],
-	[#Rule 121
-		 'arg_list', 0, undef
+	[#Rule 112
+		 'class_name', 1, undef
 	],
-	[#Rule 122
-		 'argument', 5,
+	[#Rule 113
+		 'class_name', 2,
 sub
 #line 298 "XSP.yp"
-{ make_argument( @_[0, 1], "length($_[4])" ) }
+{ $_[1] . '::' . $_[2] }
 	],
-	[#Rule 123
-		 'argument', 4,
-sub
-#line 300 "XSP.yp"
-{ make_argument( @_[0, 1, 2, 4] ) }
-	],
-	[#Rule 124
-		 'argument', 2,
+	[#Rule 114
+		 'class_name_list', 1,
 sub
 #line 301 "XSP.yp"
-{ make_argument( @_ ) }
+{ [ $_[1] ] }
+	],
+	[#Rule 115
+		 'class_name_list', 3,
+sub
+#line 302 "XSP.yp"
+{ push @{$_[1]}, $_[3]; $_[1] }
+	],
+	[#Rule 116
+		 'class_suffix', 2,
+sub
+#line 305 "XSP.yp"
+{ $_[2] }
+	],
+	[#Rule 117
+		 'class_suffix', 3,
+sub
+#line 306 "XSP.yp"
+{ $_[1] . '::' . $_[3] }
+	],
+	[#Rule 118
+		 'file_name', 1,
+sub
+#line 308 "XSP.yp"
+{ '-' }
+	],
+	[#Rule 119
+		 'file_name', 3,
+sub
+#line 309 "XSP.yp"
+{ $_[1] . '.' . $_[3] }
+	],
+	[#Rule 120
+		 'file_name', 3,
+sub
+#line 310 "XSP.yp"
+{ $_[1] . '/' . $_[3] }
+	],
+	[#Rule 121
+		 'arg_list', 1,
+sub
+#line 312 "XSP.yp"
+{ [ $_[1] ] }
+	],
+	[#Rule 122
+		 'arg_list', 3,
+sub
+#line 313 "XSP.yp"
+{ push @{$_[1]}, $_[3]; $_[1] }
+	],
+	[#Rule 123
+		 'arg_list', 0, undef
+	],
+	[#Rule 124
+		 'argument', 5,
+sub
+#line 317 "XSP.yp"
+{ make_argument( @_[0, 1], "length($_[4])" ) }
 	],
 	[#Rule 125
-		 'value', 1, undef
+		 'argument', 4,
+sub
+#line 319 "XSP.yp"
+{ make_argument( @_[0, 1, 2, 4] ) }
 	],
 	[#Rule 126
-		 'value', 2,
+		 'argument', 2,
 sub
-#line 304 "XSP.yp"
-{ '-' . $_[2] }
+#line 320 "XSP.yp"
+{ make_argument( @_ ) }
 	],
 	[#Rule 127
 		 'value', 1, undef
 	],
 	[#Rule 128
-		 'value', 1, undef
+		 'value', 2,
+sub
+#line 323 "XSP.yp"
+{ '-' . $_[2] }
 	],
 	[#Rule 129
 		 'value', 1, undef
 	],
 	[#Rule 130
-		 'value', 4,
-sub
-#line 308 "XSP.yp"
-{ "$_[1]($_[3])" }
+		 'value', 1, undef
 	],
 	[#Rule 131
-		 'value_list', 1, undef
+		 'value', 1, undef
 	],
 	[#Rule 132
-		 'value_list', 3,
+		 'value', 4,
 sub
-#line 313 "XSP.yp"
-{ "$_[1], $_[2]" }
+#line 327 "XSP.yp"
+{ "$_[1]($_[3])" }
 	],
 	[#Rule 133
-		 'value_list', 0,
-sub
-#line 314 "XSP.yp"
-{ "" }
+		 'value_list', 1, undef
 	],
 	[#Rule 134
-		 'special_blocks', 1,
+		 'value_list', 3,
 sub
-#line 318 "XSP.yp"
-{ [ $_[1] ] }
+#line 332 "XSP.yp"
+{ "$_[1], $_[2]" }
 	],
 	[#Rule 135
-		 'special_blocks', 2,
-sub
-#line 320 "XSP.yp"
-{ [ @{$_[1]}, $_[2] ] }
-	],
-	[#Rule 136
-		 'special_blocks', 0, undef
-	],
-	[#Rule 137
-		 'special_block', 3,
-sub
-#line 324 "XSP.yp"
-{ $_[2] }
-	],
-	[#Rule 138
-		 'special_block', 2,
-sub
-#line 326 "XSP.yp"
-{ [] }
-	],
-	[#Rule 139
-		 'special_block_start', 1,
-sub
-#line 329 "XSP.yp"
-{ push_lex_mode( $_[0], 'special' ) }
-	],
-	[#Rule 140
-		 'special_block_end', 1,
-sub
-#line 331 "XSP.yp"
-{ pop_lex_mode( $_[0], 'special' ) }
-	],
-	[#Rule 141
-		 'lines', 1,
+		 'value_list', 0,
 sub
 #line 333 "XSP.yp"
+{ "" }
+	],
+	[#Rule 136
+		 'expression', 1, undef
+	],
+	[#Rule 137
+		 'expression', 3,
+sub
+#line 339 "XSP.yp"
+{ "$_[1] & $_[3]" }
+	],
+	[#Rule 138
+		 'expression', 3,
+sub
+#line 341 "XSP.yp"
+{ "$_[1] | $_[3]" }
+	],
+	[#Rule 139
+		 'special_blocks', 1,
+sub
+#line 345 "XSP.yp"
 { [ $_[1] ] }
 	],
+	[#Rule 140
+		 'special_blocks', 2,
+sub
+#line 347 "XSP.yp"
+{ [ @{$_[1]}, $_[2] ] }
+	],
+	[#Rule 141
+		 'special_blocks', 0, undef
+	],
 	[#Rule 142
+		 'special_block', 3,
+sub
+#line 351 "XSP.yp"
+{ $_[2] }
+	],
+	[#Rule 143
+		 'special_block', 2,
+sub
+#line 353 "XSP.yp"
+{ [] }
+	],
+	[#Rule 144
+		 'special_block_start', 1,
+sub
+#line 356 "XSP.yp"
+{ push_lex_mode( $_[0], 'special' ) }
+	],
+	[#Rule 145
+		 'special_block_end', 1,
+sub
+#line 358 "XSP.yp"
+{ pop_lex_mode( $_[0], 'special' ) }
+	],
+	[#Rule 146
+		 'lines', 1,
+sub
+#line 360 "XSP.yp"
+{ [ $_[1] ] }
+	],
+	[#Rule 147
 		 'lines', 2,
 sub
-#line 334 "XSP.yp"
+#line 361 "XSP.yp"
 { push @{$_[1]}, $_[2]; $_[1] }
 	]
 ],
@@ -2940,7 +3061,7 @@ sub
     bless($self,$class);
 }
 
-#line 336 "XSP.yp"
+#line 363 "XSP.yp"
 
 
 use ExtUtils::XSpp::Lexer;
