@@ -36,6 +36,10 @@ methods in the class handle.
 
 =cut
 
+# internal list of all the non-empty class objects, either defined by the
+# parser or created by plugins; does not include dummy base class objects
+my %all_classes;
+
 sub init {
   my $this = shift;
   my %args = @_;
@@ -45,6 +49,14 @@ sub init {
   $this->{BASE_CLASSES} = $args{base_classes} || [];
   $this->add_methods( @{$args{methods}} ) if $args{methods};
   $this->{CATCH}     = $args{catch};
+
+  $all_classes{$this->cpp_name} = $this unless $this->empty;
+
+  # TODO check the Perl name of the base class?
+  foreach my $base ( @{$this->base_classes} ) {
+    $base = $all_classes{$base->cpp_name}
+        if $all_classes{$base->cpp_name};
+  }
 }
 
 =head2 add_methods
@@ -81,6 +93,8 @@ sub add_methods {
       # FIXME: Should there be else{croak}?
       push @{$this->{METHODS}}, $meth;
   }
+
+  $all_classes{$this->cpp_name} = $this unless $this->empty;
 }
 
 sub print {
@@ -89,6 +103,7 @@ sub print {
   my $out = $this->SUPER::print( $state );
 
   foreach my $m ( @{$this->methods} ) {
+    next if $m->can( 'access' ) && $m->access ne 'public';
     $out .= $m->print( $state );
   }
 
@@ -132,9 +147,14 @@ Each of the methods is an C<ExtUtils::XSpp::Node::Method>
 Returns the internal reference to the array of base classes of
 this class.
 
+If the base classes have been defined in the same file, these are the
+complete class objects including method definitions, otherwise only
+the C++ and Perl name of the class are available as attributes.
+
 =cut
 
 sub methods { $_[0]->{METHODS} }
 sub base_classes { $_[0]->{BASE_CLASSES} }
+sub empty { !$_[0]->methods || !@{$_[0]->methods} }
 
 1;
